@@ -17,7 +17,7 @@
 #'    calculated
 #'    (by default: exp(seq(log(0.1),log(10),length.out = 100)))
 #' @param C growth oscillation amplitude (default: 0)
-#' @param WP onset of the first oscillation relative to t0 (winter point, default: 0)
+#' @param ts onset of the first oscillation relative to t0 (summer point, default: 0)
 #' @param MA number indicating over how many length classes the moving average
 #'    should be performed (defalut: 5, for
 #'    more information see \link{lfqRestructure}).
@@ -28,6 +28,11 @@
 #' @param hide.progressbar logical; should the progress bar be hidden? (default: FALSE)
 #' @param plot logical; indicating if plot with restructured frequencies and growth curves should
 #'    be displayed
+#' @param contour if used in combination with response surface analysis, contour lines
+#'    are displayed rather than the score as text in each field of the score plot. Usage
+#'    can be logical (e.g. TRUE) or by providing a numeric which indicates the
+#'    number of levels (\code{nlevels} in \code{\link{contour}}). By default FALSE.
+#' @param plot_title logical; indicating whether title to score plots should be displayed
 #'
 #' @examples
 #' \donttest{
@@ -35,12 +40,12 @@
 #'
 #' # K-Scan
 #' output <- ELEFAN(x = synLFQ4, Linf_fix = 80,
-#'    K_range = seq(0.3,0.7,0.1),C = 0.75, WP = 0.5, MA = 11)
+#'    K_range = seq(0.3,0.7,0.1),C = 0.75, ts = 0.5, MA = 11)
 #' plot(output)
 #'
 #' # Surface response analysis
 #' output2 <- ELEFAN(synLFQ4, Linf_range = seq(78,82,1),
-#'    K_range = seq(0.3,0.7,0.1),C = 0.75, WP = 0.5, MA = 11)
+#'    K_range = seq(0.3,0.7,0.1),C = 0.75, ts = 0.5, MA = 11, contour = 3)
 #' plot(output2)
 #'}
 #'
@@ -82,7 +87,9 @@
 #'        \item \strong{C}: amplitude of growth oscillation
 #'          (if \code{seasonalised} = TRUE),
 #'        \item \strong{ts}: summer point of oscillation (ts = WP - 0.5)
-#'          (if \code{seasonalised} = TRUE);
+#'          (if \code{seasonalised} = TRUE),
+#'        \item \strong{phiL}: growth performance index defined as
+#'          phiL = log10(K) + 2 * log10(Linf);
 #'      }
 #'   \item \strong{Rn_max}: highest score value
 #' }
@@ -135,11 +142,12 @@
 
 ELEFAN <- function(x, Linf_fix = NA, Linf_range = NA,
                    K_range = exp(seq(log(0.1), log(10), length.out=100)),
-                   C = 0, WP = 0,
+                   C = 0, ts = 0,
                    MA = 5, addl.sqrt = FALSE,
                    agemax = NULL, flagging.out = TRUE,
                    hide.progressbar = FALSE,
-                   plot = FALSE){
+                   plot = FALSE, contour = FALSE,
+                   plot_title = TRUE){
 
   res <- x
   classes <- res$midLengths
@@ -150,7 +158,7 @@ ELEFAN <- function(x, Linf_fix = NA, Linf_range = NA,
   n_samples <- dim(catch)[2]
   n_classes <- length(classes)
 
-  ts <- WP - 0.5
+  #ts <- WP - 0.5
 
   if(is.na(Linf_fix) & is.na(Linf_range[1])) Linf_range <- seq(classes[n_classes]-5,classes[n_classes]+5,1) ### OLD: c(classes[n_classes]-5,classes[n_classes]+5)
 
@@ -223,9 +231,14 @@ ELEFAN <- function(x, Linf_fix = NA, Linf_range = NA,
     image(x = Linfs,
           y = Ks,
           z = t(score_mat), col=colorRampPalette(c("yellow","red"), space="Lab")(5),
-          main = 'Response surface analysis', ylab = 'K', xlab='Linf')
+          ylab = 'K', xlab='Linf')
+    if(plot_title)  title('Response surface analysis', line = 2)
     #grid (NULL,NULL, lty = 6, col = "cornsilk2")
-    text(x=plot_dat$Var2,y=plot_dat$Var1,round(as.numeric(plot_dat$value),digits = 2),cex = 0.6)
+    if(contour){
+      contour(x = Linfs, y = Ks, z = t(score_mat), add = TRUE)
+    }else if(is.numeric(contour)){
+      contour(x = Linfs, y = Ks, z = t(score_mat), add = TRUE, nlevels = contour)
+    }else text(x=plot_dat$Var2,y=plot_dat$Var1,round(as.numeric(plot_dat$value),digits = 2),cex = 0.6)
   }else{
     if(all(Ks %in% exp(seq(log(0.1),log(10),length.out=100)))){
       K_labels <- c(seq(0.1,1,0.1),2:10)
@@ -247,21 +260,25 @@ ELEFAN <- function(x, Linf_fix = NA, Linf_range = NA,
     mtext(text = expression(paste("Growth performance index (",phi,"')")),side = 1,line = 8.5)
     grid(nx = 0, NULL, lty = 6, col = "gray40")
     abline(v = K_ats, lty = 6, col = "gray40")
-    title("K-Scan", line = 2)
+    if(plot_title) title("K-Scan", line = 2)
     par(op)
   }
 
-  Rn_max <- max(score_mat, na.rm = TRUE)
-  idxs <- which(score_mat == Rn_max, arr.ind = TRUE)
+  Rn_max <- max(score_mat, na.rm = TRUE)[1]
+  idxs <- which(score_mat == Rn_max, arr.ind = TRUE)[1,]
   Linfest <- as.numeric(as.character(colnames(score_mat)[idxs[2]]))
   Kest <- as.numeric(as.character(rownames(score_mat)[idxs[1]]))
   tanchest <- as.numeric(as.character(ESP_tanch_L[idxs[1],idxs[2]]))
 
+  # growth performance index
+  phiL <- log10(Kest) + 2 * log10(Linfest)
+
   pars <- list(Linf = Linfest,
                K = Kest,
                t_anchor = tanchest,
                C = C,
-               ts = ts)
+               ts = ts,
+               phiL = phiL)
 
   final_res <- lfqFitCurves(lfq = res, par=pars,
                             flagging.out = flagging.out,
