@@ -16,21 +16,38 @@
 #' @param yaxis2 which second y-axis should be plotted for type = "ypr"? Either "B_R" (biomass
 #'    per recruit; default), "B_R.rel" (relative biomass per recruit), or "B_R.percent"
 #'    (percentage biomass per recruit)
+#' @param yaxis_iso determines label and scale of y axis of Isopleth graph. Either "Lc"
+#'    (default) for length at first capture or "Lc/Linf" for the relation of length
+#'    at first capture to the infinite length
 #' @param identify logical; indicating whether points in the graph are supposed to be identified by
 #'    clicking on them (uses \code{\link{locator}} function). To stop press right mouse click.
 #'    (default: TRUE).
 #' @param mark logical; if value of choosen points should be displayed in graph (default: TRUE)
+#' @param contour used in combination with the Isopleth graph. Usage
+#'    can be logical (e.g. TRUE) or providing a numeric which indicates the
+#'    number of levels (\code{nlevels} in \code{\link{contour}}). By default TRUE.
 #' @param ... optional parameters of plot function
 #'
 #' @examples
 #' \dontrun{
-#' # YPR
-#' # age structured data
-#' # Nemipterus marginatus
-#' # threadfin <- list(Winf = 286,K = 0.37, t0 = -0.2, M = 1.1, tr = 0.4)
+#' # Nemipterus marginatus - age structured data
+#' threadfin <- list(Winf = 286,K = 0.37, t0 = -0.2, M = 1.1, tr = 0.4)
+#'
+#' output <- predict_mod(threadfin, FM_change = seq(0,6,0.1),
+#'    tc_change = seq(0.2,1,0.2), type = 'ypr')  #where it is maximal  = MSY
+#' plot(output)
+#'
+#' # hake - length structured data
+#' data(hake)
+#' hake$Lr <- 35
+#' select.list <- list(selecType = 'trawl_ogive', L50 = 20, L75 = 24)
+#' output <- predict_mod(param = hake, FM_change = seq(0,0.4,0.05),
+#'                       curr.E = 0.4, curr.Lc = 40,
+#'                       Lc_change = seq(5,80,1), s_list = select.list,
+#'                       type = 'ypr', plot = FALSE)
+#' plot(output, type = "Isopleth", xaxis1 = "FM", yaxis1 = "Y_R.rel",
+#'    identify = FALSE)
 #'
-#' # predict_mod(threadfin, FM_change = seq(0,6,0.1),
-#' #    tc_change = seq(0.2,1,0.2), type = 'ypr')  #where it is maximal  = MSY
 #'}
 #' @importFrom grDevices colorRampPalette dev.new rgb
 #' @importFrom graphics mtext par plot axis contour identify image legend lines locator points rect segments text
@@ -43,37 +60,68 @@
 
 plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
                              yaxis1 = "Y_R.rel", yaxis2 = "B_R.rel",
-                             identify = FALSE, mark = TRUE,...){
+                             yaxis_iso = "Lc",
+                             identify = FALSE, mark = FALSE, contour = TRUE, ...){
   pes <- x
 
   # function for identifying Lc and yield/biomass values in plot
-  image.identifier <- function(xyz, mark=mark, digits=3){
+  image.identifier <- function(xyz, markII=TRUE, digits=2){
     intiX <- (xyz$x[2]-xyz$x[1])/2
     intiY <- (xyz$y[2]-xyz$y[1])/2
     newX <- c(xyz$x - intiX,xyz$x[length(xyz$x)]+intiX)
     newY <- c(xyz$y - intiY,xyz$y[length(xyz$y)]+intiY)
     nx <- length(xyz$x)
     ny <- length(xyz$y)
-    res <- data.frame()
+    mesi <- data.frame()
     xy <- locator(1)
     while(!is.null(xy)){
       xbin <- as.numeric(cut(xy$x,newX))
       ybin <- as.numeric(cut(xy$y,newY))
-      if(mark){
-        points(xy$x,xy$y,pch=19,cex=.5,col="blue")
-        text(xy$x,xy$y,format(xyz$z[xbin,ybin],digits=digits),adj=-.2,col="blue")
-      }
       cat("[",xbin,",",ybin,"] = ",xyz$z[xbin,ybin],"\n",sep='')
       lcc <- xy$y * pes$Linf
-      res <- rbind(res,data.frame(i=xbin,j=ybin,x=xy$x,y=xy$y,z=xyz$z[xbin,ybin],Lc=lcc))
+      mesi <- rbind(mesi,data.frame(i=xbin,j=ybin,x=xy$x,y=xy$y,z=xyz$z[xbin,ybin],Lc=lcc))
+      rm(xy)
       xy <- locator(1)
     }
-    colnames(res) <- c("i","j",p.FE,"Lc/Linf",p.yield,"Lc")
-    res
+    if(markII){
+      points(mesi$x,mesi$y,pch=19,cex=.5,col="blue")
+      text(mesi$x,mesi$y,format(mesi$z,digits=digits),adj=-.2,col="blue")
+    }
+    colnames(mesi) <- c("i","j",p.FE,"Lc/Linf",p.yield,"Lc")
+    # if(mark){
+    #   points(xy$x,xy$y,pch=19,cex=.5,col="blue")
+    #   text(xy$x,xy$y,format(xyz$z[xbin,ybin],digits=digits),adj=-.2,col="blue")
+    # }
+    mesi
   }
 
   #THOMPBELL
-  if("totals" %in% names(pes)){
+  if("totY" %in% names(pes)){
+    df_Es <- pes$df_Es
+
+    if(xaxis1 == "FM"){
+      px <- pes$FM_change
+      xlabel1 <- "Fishing mortality"
+
+      N05 <- df_Es$F05
+      Nmax <- df_Es$Fmsy
+      if(length(N05) == 1){
+        legend.lab <- c("F0.5","Fmsy")
+      }else legend.lab <- c("Fmsy")
+      if("currents" %in% names(pes)) curr_markX <- pes$currents$curr.F
+    }else{
+      px <- pes$E_change
+      xlabel1 <- "Exploitation rate"
+
+      N05 <- df_Es$E05
+      Nmax <- df_Es$Emsy
+      if(length(N05) == 1){
+        legend.lab <- c("E0.5","Emsy")
+      }else legend.lab <- c("Emsy")
+      if("currents" %in% names(pes)) curr_markX <- pes$currents$curr.E
+    }
+
+
     #save x axis positions
     max_val <- round(max(pes$totV,na.rm=TRUE),digits=0)
     dim_val <- 10 ^ (nchar(max_val)-1)
@@ -85,30 +133,76 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
     #   max_val <- round(max(pes$totV,na.rm=TRUE),digits=0)
     #   dim_val <- 10 ^ (nchar(max_val)-1)
 
-    op <- par(oma = c(1, 1, 1.5, 1),new=FALSE,mar = c(5, 4, 4, 6) + 0.3)
-    plot(pes$Xfact,pes$totV, type ='o',ylab='Value',xlab='F-factor X',
-         col ='darkorange', ylim = c(0,ceiling(max_val/dim_val)*dim_val),
+
+    py <- pes$totY[1:length(px)]
+    py2 <- pes$meanB[1:length(px)]
+
+    #op <- par(oma = c(1, 1, 1.5, 1),new=FALSE,mar = c(5, 4, 4, 6) + 0.3)
+    plot(px,py, type ='l',ylab='Yield',xlab= xlabel1,
+         col ='black', ylim = c(0,ceiling(max_yiel/dim_yiel)*dim_yiel),
          lwd=1.6)
-    par(new=TRUE)
-    plot(pes$Xfact,pes$totY,type ='o',ylab='',xlab='',
-         col='dodgerblue',lwd=1.6,axes=FALSE,
-         ylim = c(0,ceiling(max_yiel/dim_yiel) * dim_yiel))
-    axis(4,at=pretty(c(0,pes$totY)))
-    mtext("Yield", side=4, line=2)
-    par(new=TRUE)
-    plot(pes$Xfact,pes$meanB,type='o',axes=FALSE,ylab='',xlab='',
-         col = 'darkgreen',lwd=1.6,
-         ylim = c(0,ceiling(max_bio/dim_bio)*dim_bio))    # draw lines with small intervals: seq(0,max(),0.05) but y as to be dependent of x (formula of calculaiton of y)
-    axis(4,at=pretty(c(0,pes$meanB)),line = 3)
-    mtext("Biomass", side=4, line=5)
+    # F or E max
+    segments(x0 = -1, x1 = Nmax, y0 = py[which(px == Nmax)],
+             y1 = py[which(px == Nmax)],
+             col= 'goldenrod1',lty = 2, lwd=1.6)
+    segments(x0 = Nmax, x1 = Nmax, y0 = -1, y1 = py[which(px == Nmax)],
+             col= 'goldenrod1',lty = 2, lwd=1.6)
 
-    par(oma = c(0, 0, 0, 0), new = TRUE)
-    legend("top", c("value", "yield", "biomass"), xpd = TRUE,
-           horiz = TRUE, inset = c(0, -0.1), bty = "n",lty = 1,seg.len = 0.7,
-           col = c('darkorange','dodgerblue','darkgreen'), cex = 0.8,lwd=2,
-           text.width=0.3,x.intersp=0.3)
-    par(op)
+    # current Exploitation rate or fishing mortality
+    if(!is.null(pes$currents) & mark){
+      currents <- pes$currents
+      if(!is.na(currents$curr.E) & yaxis1 == "Y_R" | yaxis1 == "Y_R.rel"){
+        px1 <- ifelse(xaxis1 == "FM",currents$curr.F, currents$curr.E)
+        py1 <- currents$curr.Y
+        points(px1,py1, pch = 16, col="grey30")
+        abline(v=px1, col="grey30",lty=2)
+      }
+    }
 
+    # Biomass
+    par(new=TRUE)
+    plot(px,py2,type ='l',ylab='',xlab='',
+         col='blue',lwd=1.6,axes=FALSE)
+    axis(4,at=pretty(c(0,max(pes$meanB))),col = "blue", col.axis="blue")
+    mtext("Biomass", side=4, line=2, col = "blue", cex=1)
+    # F or E 05
+    segments(x0 = -1, x1 = N05, y0 = py2[which(px == N05)], y1 = py2[which(px == N05)],
+             col= 'red',lty = 3, lwd=1.5)
+    segments(x0 = N05, x1 = N05, y0 = -1, y1 = py2[which(px == N05)],
+             col= 'red',lty = 3, lwd=1.5)
+    # current Exploitation rate or fishing mortality
+    if(!is.null(pes$currents) & mark){
+      currents <- pes$currents
+      if(!is.na(currents$curr.E) & yaxis1 == "B_R" | yaxis1 == "B_R.rel"){
+        px1 <- ifelse(xaxis1 == "FM",currents$curr.F, currents$curr.E)
+        py1 <- currents$curr.B
+        points(px1,py1, pch = 16, col="grey30")
+        abline(v=px1, col="grey30",lty=2)
+      }
+    }
+    # Legend
+    legend("top", legend = legend.lab, xpd = TRUE, horiz = TRUE,
+           inset = c(0,0), bty = "n", lty = c(1,2), col = c("red","goldenrod1"),
+           seg.len = 1,pt.cex = 2, x.intersp = c(0.7,0.7),merge=TRUE,
+           y.intersp = -2, box.lty=0,cex=0.8, lwd =2)
+
+    # Value if present
+    if(any(pes$totV != 0)){
+      py3 <- pes$totV[1:length(px)]
+      par(new=TRUE)
+      plot(px,py3,type='l',axes=FALSE,ylab='',xlab='',
+           col = 'darkgreen',lwd=1.6,
+           ylim = c(0,ceiling(max_val/dim_val)*dim_val))    # draw lines with small intervals: seq(0,max(),0.05) but y as to be dependent of x (formula of calculaiton of y)
+      axis(4,at=pretty(c(0,pes$totV)),line = 3,col.axis="darkgreen",col="darkgreen")
+      mtext("Value", side=4, line=5,col="darkgreen")
+    }
+
+    # #par(oma = c(0, 0, 0, 0), new = TRUE)
+    # legend("top", c("value", "yield", "biomass"), xpd = TRUE,
+    #        horiz = TRUE, inset = c(0, -0.1), bty = "n",lty = 1,seg.len = 0.7,
+    #        col = c('darkorange','dodgerblue','darkgreen'), cex = 0.8,lwd=2,
+    #        text.width=0.3,x.intersp=0.3)
+    # #par(op)
   }
 
   # THOMP BELL WITH LC change - ISOPLETHS
@@ -117,14 +211,17 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
     p.FE <- xaxis1
     p.B <- yaxis2
     xlabel1 <- ifelse(xaxis1 == "FM", "Fishing mortality", "Exploitation rate")
-    ylabel1 <- ifelse(yaxis1 == "Y_R", "Y/R", "rel. Y/R")
+    #ylabel1 <- ifelse(yaxis1 == "Y_R", "Y/R", "rel. Y/R")
+    ylabel_iso <- ifelse(yaxis_iso == "Lc", "Lc", "Lc / Linf")
 
     Lc_change <- pes$Lc_change
     FM_change <- pes$FM_change
     if(p.FE == "FM"){
       px <- FM_change
+      if("currents" %in% names(pes)) curr_markX <- pes$currents$curr.F
     }else{
       px <- FM_change/(FM_change + pes$M)
+      if("currents" %in% names(pes)) curr_markX <- pes$currents$curr.E
     }
 
     if(p.yield == "Y_R.rel" | p.yield == "Y_R"){
@@ -140,22 +237,45 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
     # colours for plot
     pal <- colorRampPalette(rev(c(
       rgb(1,0.5,0.5), rgb(1,1,0.5), rgb(0.5,1,1), rgb(0.5,0.5,1))))
+    if(yaxis1 == "B_R" | yaxis1 == "B_R.rel"){
+      pal <- colorRampPalette(c(
+        rgb(1,0.5,0.5), rgb(1,1,0.5), rgb(0.5,1,1), rgb(0.5,0.5,1)))
+    }
 
     m <- list(x = px,
               y = Lc_change,
               z = pz)
 
+    if("currents" %in% names(pes)) curr_markY <- pes$currents$curr.Lc
+
+    if(yaxis_iso != "Lc" & "Linf" %in% names(pes)){
+      m$y <- Lc_change/pes$Linf
+      if("currents" %in% names(pes)) curr_markY <- pes$currents$curr.Lc/pes$Linf
+    }
+
     #plot
     if(identify == TRUE){
       dev.new(noRStudioGD = TRUE)
     }
     image(m, col=pal(100),
-          xlab = xlabel1, ylab = 'Lc')
-    contour(m, add=TRUE)
+          xlab = xlabel1, ylab = ylabel_iso)
+    if(is.numeric(contour)){
+      contour(m, add=TRUE, nlevels = contour)
+    }else if(contour == TRUE){
+      contour(m, add=TRUE)
+    }
+
+    if("currents" %in% names(pes) & mark){
+      points(x = curr_markX, y=curr_markY, pch=16, col="grey30")
+      abline(v=curr_markX, col="grey30",lty=2)
+      abline(h=curr_markY, col="grey30",lty=2)
+    }
     #mtext("Yield", line=0.5, side=3)
     if(identify == TRUE) image.identifier(m)
   }
 
+
+
   # YPR
   if("list_Lc_runs" %in% names(pes) |
      "list_tc_runs" %in% names(pes)){
@@ -174,6 +294,7 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
     xlabel1 <- ifelse(xaxis1 == "FM", "Fishing mortality", "Exploitation rate")
     ylabel1 <- ifelse(yaxis1 == "Y_R", "Y/R", "rel. Y/R")
     ylabel2 <- ifelse(yaxis2 == "B_R", "B/R", "B/R [%]")
+    ylabel_iso <- ifelse(yaxis_iso == "Lc", "Lc", "Lc / Linf")
 
 
     df_Es <- pes$df_Es
@@ -181,33 +302,40 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
       N01 <- df_Es$F01
       N05 <- df_Es$F05
       Nmax <- df_Es$Fmsy
-      legend.lab <- c("F0.1","F0.5","Fmsy")
+      if(length(N05) == 1){
+        legend.lab <- c("F0.1","F0.5","Fmsy")
+      }else legend.lab <- c("F0.1","Fmsy")
+      if("currents" %in% names(pes)) curr_markX <- pes$currents$curr.F
     }else{
       N01 <- df_Es$E01
       N05 <- df_Es$E05
       Nmax <- df_Es$Emsy
-      legend.lab <- c("E0.1","E0.5","Emsy")
+      if(length(N05) == 1){
+        legend.lab <- c("E0.1","E0.5","Emsy")
+      }else legend.lab <- c("E0.1","Emsy")
+      if("currents" %in% names(pes)) curr_markX <- pes$currents$curr.E
     }
 
     #standard plot (ypr vs. E or FM)
     if(type == 'ypr'){
       #Plot
-      op <- par(mfrow=c(1,1),new=F, mar = c(5, 4, 4, 4) + 0.3)
+      #op <- par(mfrow=c(1,1),new=F, mar = c(5, 4, 4, 4) + 0.3)
 
       #plot Y/R & B/R
-      label <- ifelse("tc" %in% names(pes), "tc", "Lc")
+      label <- ifelse("Lc" %in% names(pes),  "Lc","tc")
       tc_Lc_start <- which(tc_Lc == max(tc_Lc,na.rm=T))
       p.dat <- list_tc_Lc_runs[[tc_Lc_start]]
       py <- p.dat[,which(names(p.dat) == p.yield)]
       px <- p.dat[,which(names(p.dat) == p.FE)]
-      offset_text <- py[length(py)] * 0.02
+      offset_text <- py[length(py)] * 0.05
+      offset_x <- py[length(px)] * 0.1
+      runs <- sapply(strsplit(names(list_tc_Lc_runs),split = "_"), "[[",2)
 
       plot(px, py, type = 'l', ylim =c(0,max(py, na.rm = TRUE)*1.2),
-           ylab = ylabel1, xlab = xlabel1, lty=tc_Lc_start)  #,...
-      text(x = px[length(px)],
-           y = (py[length(py)] +
-                  offset_text),
-           labels = bquote(.(label)[.(names(list_tc_Lc_runs)[tc_Lc_start])]))
+           ylab = ylabel1, xlab = xlabel1, lty=tc_Lc_start,...)
+      text(x = px[length(px)] - offset_x,
+           y = py[length(py)] + offset_text,
+           labels = bquote(.(label)[.(round(as.numeric(as.character(runs[tc_Lc_start])),2))]))
       seq_tc_Lc <- 1:length(list_tc_Lc_runs)
       seq_tc_Lc <- seq_tc_Lc[-tc_Lc_start]
       for(j in seq_tc_Lc){
@@ -220,7 +348,7 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
         text(x = px[length(px)],
              y = (py[length(py)] +
                     offset_text),
-             labels = bquote(.(label)[.(names(list_tc_Lc_runs)[j])]))
+             labels = bquote(.(label)[.(round(as.numeric(as.character(runs[j])),2))]))
       } # only works with plotting whole graph if values are not getting bigger right? because otherwise graphs is not insed plotting area
 
       # reference points
@@ -234,9 +362,9 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
         }else  add_shift <- 1
         segments(x0 = -1, x1 = N01, y0 = py[which(px == N01)],
                  y1 = py[which(px == N01)],
-                 col= 'darkgreen',lty = 2, lwd=1.5)
+                 col= 'darkgreen',lty = 1, lwd=1.5)
         segments(x0 = N01, x1 = N01, y0 = -1, y1 = py[which(px == N01)],
-                 col= 'darkgreen',lty = 2, lwd=1.5)
+                 col= 'darkgreen',lty = 1, lwd=1.5)
         # F or E max
         segments(x0 = -1, x1 = Nmax, y0 = py[which(px == Nmax)]*add_shift,
                  y1 = py[which(px == Nmax)]*add_shift,
@@ -244,10 +372,18 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
         segments(x0 = Nmax*add_shift, x1 = Nmax*add_shift, y0 = -1, y1 = py[which(px == Nmax)],
                  col= 'goldenrod1',lty = 2, lwd=1.5)
         # Legend
-        legend("top", legend = legend.lab, xpd = TRUE, horiz = TRUE,
-               inset = c(0,0), bty = "n", lty = 2, col = c("darkgreen","red","goldenrod1"),
-               seg.len = 1,pt.cex = 2, x.intersp = c(0.7,0.7,0.7),merge=TRUE,
-               y.intersp = -2, box.lty=0,cex=0.8, lwd =2)
+        if(length(N05) == 1){
+          legend("top", legend = legend.lab, xpd = TRUE, horiz = TRUE,
+                 inset = c(0,0), bty = "n", lty = c(1,3,2), col = c("darkgreen","red","goldenrod1"),
+                 seg.len = 1,pt.cex = 2, x.intersp = c(0.7,0.7,0.7),merge=TRUE,
+                 y.intersp = -2, box.lty=0,cex=0.8, lwd =2)
+        }else{
+          legend("top", legend = legend.lab, xpd = TRUE, horiz = TRUE,
+                 inset = c(0,0), bty = "n", lty = c(1,2), col = c("darkgreen","goldenrod1"),
+                 seg.len = 1,pt.cex = 2, x.intersp = c(0.7,0.7,0.7),merge=TRUE,
+                 y.intersp = -2, box.lty=0,cex=0.8, lwd =2)
+        }
+
 
         # current Exploitation rate or fishing mortality
         if(!is.null(pes$currents)){
@@ -256,6 +392,7 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
             px <- ifelse(p.FE == "FM",currents$curr.F, currents$curr.E)
             py <- ifelse(p.yield == "Y_R",currents$curr.YPR,currents$curr.YPR.rel)
             points(px,py, pch = 16)
+            abline(v=px, col="grey30",lty=2)
           }
         }
       }
@@ -284,11 +421,11 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
         py2 <- p.dat[,which(names(p.dat) == p.B)]
         # F or E 0.5
         segments(x0 = -1, x1 = N05, y0 = py2[which(px == N05)], y1 = py2[which(px == N05)],
-                 col= 'red',lty = 2, lwd=1.5)
+                 col= 'red',lty = 3, lwd=1.5)
         segments(x0 = N05, x1 = N05, y0 = -1, y1 = py2[which(px == N05)],
-                 col= 'red',lty = 2, lwd=1.5)
+                 col= 'red',lty = 3, lwd=1.5)
       }
-      par(op)
+      #par(op)
     }
 
     #Isopleths
@@ -312,28 +449,45 @@ plot.predict_mod <- function(x, type = 'ypr', xaxis1 = "FM",
         colnames(mat_FM_Lc_com.Y) <- round(Lc_change/pes$Linf,digits = 2)
 
         m <- list(x = px,
-                  y = Lc_change/pes$Linf,
+                  y = Lc_change,
                   z = mat_FM_Lc_com.Y)
 
+        if("currents" %in% names(pes)) curr_markY <- pes$currents$curr.Lc
+
+        if(yaxis_iso != "Lc" & "Linf" %in% names(pes)){
+          m$y <- Lc_change/pes$Linf
+          if("currents" %in% names(pes)) curr_markY <- pes$currents$curr.Lc/pes$Linf
+        }
+
         # colours for plot
         pal <- colorRampPalette(rev(c(
           rgb(1,0.5,0.5), rgb(1,1,0.5), rgb(0.5,1,1), rgb(0.5,0.5,1)
         )))
+        if(yaxis1 == "B_R" | yaxis1 == "B_R.rel"){
+          pal <- colorRampPalette(c(
+            rgb(1,0.5,0.5), rgb(1,1,0.5), rgb(0.5,1,1), rgb(0.5,0.5,1)))
+        }
 
         #plot
         if(identify == TRUE){
           dev.new(noRStudioGD = TRUE)
         }
         image(m, col=pal(100),
-              xlab = xlabel1, ylab = 'Lc / Linf')
-        contour(m, add=TRUE)
+              xlab = xlabel1, ylab = ylabel_iso)
+        if(is.numeric(contour)){
+          contour(m, add=TRUE, nlevels = contour)
+        }else if(contour == TRUE){
+          contour(m, add=TRUE)
+        }
+
         #mtext("Yield", line=0.5, side=3)
+        if("currents" %in% names(pes) & mark){
+          points(x = curr_markX, y=curr_markY, pch=16, col="grey30")
+          abline(v=curr_markX, col="grey30",lty=2)
+          abline(h=curr_markY, col="grey30",lty=2)
+        }
         if(identify == TRUE) image.identifier(m)
       }
     }
   }
 }
-
-
-
-
